summaryrefslogtreecommitdiff
path: root/TAO/TAO_IDL/be/be_visitor_operation/rettype.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/TAO_IDL/be/be_visitor_operation/rettype.cpp')
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation/rettype.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/TAO/TAO_IDL/be/be_visitor_operation/rettype.cpp b/TAO/TAO_IDL/be/be_visitor_operation/rettype.cpp
index f513797124b..ff0c96d5d75 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation/rettype.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation/rettype.cpp
@@ -162,9 +162,10 @@ be_visitor_operation_rettype::visit_predefined_type (be_predefined_type *node)
switch (node->pt ())
{
case AST_PredefinedType::PT_pseudo:
+ case AST_PredefinedType::PT_object:
*os << bt->name ();
// If it's not TCKind, it's either TypeCode or ValueBase.
if (ACE_OS::strcmp (bt->local_name ()->get_string (), "TCKind") != 0)
{
*os << "_ptr";
@@ -162,9 +162,10 @@ be_visitor_operation_rettype::visit_predefined_type (be_predefined_type *node)
*os << bt->name ();
- // If it's not TCKind, it's either TypeCode or ValueBase.
+ // If it's not TCKind, it's either Object, TypeCode or ValueBase.
if (ACE_OS::strcmp (bt->local_name ()->get_string (), "TCKind") != 0)
{